==> apache-doris-1.2.6-src.tar.gz: apache-doris-1.2.6-src/be/test/common/resource_tls_test.cpp <==
// Licensed to the Apache Software Foundation (ASF) under one
// or more contributor license agreements.  See the NOTICE file
// distributed with this work for additional information
// regarding copyright ownership.  The ASF licenses this file
// to you under the Apache License, Version 2.0 (the
// "License"); you may not use this file except in compliance
// with the License.  You may obtain a copy of the License at
//
//   http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing,
// software distributed under the License is distributed on an
// "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
// KIND, either express or implied.  See the License for the
// specific language governing permissions and limitations
// under the License.

#include "common/resource_tls.h"

#include <gtest/gtest.h>

#include "common/configbase.h"
#include "gen_cpp/Types_types.h"

namespace doris {

class ResourceTlsTest : public testing::Test {};

TEST_F(ResourceTlsTest, EmptyTest) {
    EXPECT_TRUE(ResourceTls::get_resource_tls() == nullptr);
    EXPECT_TRUE(ResourceTls::set_resource_tls((TResourceInfo*)1) != 0);
}

TEST_F(ResourceTlsTest, NormalTest) {
    ResourceTls::init();
    EXPECT_TRUE(ResourceTls::get_resource_tls() == nullptr);
    TResourceInfo* info = new TResourceInfo();
    info->user = "testUser";
    info->group = "testGroup";
    EXPECT_TRUE(ResourceTls::set_resource_tls(info) == 0);
    TResourceInfo* getInfo = ResourceTls::get_resource_tls();
    EXPECT_STREQ("testUser", getInfo->user.c_str());
    EXPECT_STREQ("testGroup", getInfo->group.c_str());
}

} // namespace doris

==> apache-doris-2.0.15.1-src.tar.gz: apache-doris-2.0.15.1-src/be/test/common/resource_tls_test.cpp <==
// Licensed to the Apache Software Foundation (ASF) under one
// or more contributor license agreements.  See the NOTICE file
// distributed with this work for additional information
// regarding copyright ownership.  The ASF licenses this file
// to you under the Apache License, Version 2.0 (the
// "License"); you may not use this file except in compliance
// with the License.  You may obtain a copy of the License at
//
//   http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing,
// software distributed under the License is distributed on an
// "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
// KIND, either express or implied.  See the License for the
// specific language governing permissions and limitations
// under the License.

#include "common/resource_tls.h"

#include <gtest/gtest-message.h>
#include <gtest/gtest-test-part.h>

#include <memory>

#include "gen_cpp/Types_types.h"
#include "gtest/gtest_pred_impl.h"

namespace doris {

class ResourceTlsTest : public testing::Test {};

TEST_F(ResourceTlsTest, EmptyTest) {
    EXPECT_TRUE(ResourceTls::get_resource_tls() == nullptr);
    EXPECT_TRUE(ResourceTls::set_resource_tls((TResourceInfo*)1) != 0);
}

TEST_F(ResourceTlsTest, NormalTest) {
    ResourceTls::init();
    EXPECT_TRUE(ResourceTls::get_resource_tls() == nullptr);
    TResourceInfo* info = new TResourceInfo();
    info->user = "testUser";
    info->group = "testGroup";
    EXPECT_TRUE(ResourceTls::set_resource_tls(info) == 0);
    TResourceInfo* getInfo = ResourceTls::get_resource_tls();
    EXPECT_STREQ("testUser", getInfo->user.c_str());
    EXPECT_STREQ("testGroup", getInfo->group.c_str());
}

} // namespace doris
